Exception: MixinBot::InsufficientBalanceError
- Defined in:
- lib/mixin_bot/errors.rb
Overview
Raised when there is insufficient balance for a transaction (error code 20117).
Raised when there is insufficient balance for a transaction (error code 20117).